<?php


namespace Repository;

use Doctrine\ORM\EntityManager;
use Util\InstanceProvider;
use Zeedhi\DevOps\Model\Traits\TQuery;

class Budget extends RepositoryBase
{

    use TQuery;

    const ENTITY_NAME = '\Zeedhi\DevOps\Model\Projectmanagement\Entities\Budget';
    /**
     * @var EntityManager
     */
    private $entityManager;

    public function __construct()
    {
        parent::__construct(self::ENTITY_NAME);
        $this->entityManager = InstanceProvider::getEntityManager();
    }

     public function getIssueBudgetSMAccepted($issueid)
    {
        $query = <<<SQL
             SELECT NRSEQORCAMENTO AS EXTERNAL_ID
                FROM FCT_ORCAMENTO
               WHERE ISSUEID = :ISSUEID
                 AND IDATIVO = 'S'
                 AND IDSITUACAOORCAMENTO  = 'ACEITO'
SQL;
        $params = array(
            'ISSUEID' => $issueid
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

    public function getIssueBudgetSMConcluded($issueid)
    {
        $query = <<<SQL
             SELECT NRSEQORCAMENTO AS EXTERNAL_ID
                FROM FCT_ORCAMENTO
               WHERE ISSUEID = :ISSUEID
                 AND IDATIVO = 'S'
                 AND IDSITUACAOORCAMENTO  = 'CONCLUIDO'
SQL;
        $params = array(
            'ISSUEID' => $issueid
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

    public function getAllSmBudgetNotAccepted()
    {
        $query = <<<SQL
              SELECT TAS.ID FROM 
                     TASK TAS
                JOIN TASK_STATUS TS ON TAS.TASK_STATUS = TS.ID
                JOIN TASK_TYPE TT ON TT.ID = TS.TASK_TYPE AND TT.CONTROL = 'H'
                JOIN FCT_ORCAMENTO ORC ON ORC.ISSUEID = TAS.ID AND 'CONCLUIDO' = ORC.IDSITUACAOORCAMENTO
               WHERE TAS.IS_ISSUE = 'Y'
                 AND TAS.ID NOT IN (SELECT TAS.ID FROM 
                                    TASK TAS
                                    JOIN TASK_STATUS TS ON TAS.TASK_STATUS = TS.ID
                                    JOIN TASK_TYPE TT ON TT.ID = TS.TASK_TYPE AND TT.CONTROL = 'H'
                                    JOIN FCT_ORCAMENTO ORC ON ORC.ISSUEID = TAS.ID AND 'ACEITO' = ORC.IDSITUACAOORCAMENTO
                                    WHERE TAS.IS_ISSUE = 'Y')
            ORDER BY CURRENT_TASK_STATUS_IN DESC
SQL;

        return $this->getEntityManager()->getConnection()->fetchAll($query);
    }

}
