<?php
namespace Service;

use Doctrine\ORM\EntityManager;
use Util\InstanceProvider;
use Zeedhi\DevOps\Util\Utilities AS DevOpsUtilities;
use Zeedhi\DevOps\Model\Projectmanagement\Entities;

class TaskReplanningReason
{
    /**
     * @var EntityManager
     */
    private $entityManager;
    
    public function __construct(EntityManager $entityManager)
    {
         $this->entityManager = $entityManager;
    }
    
    public function findTaskReplanningReason($conditions)
    {
        $environment = InstanceProvider::getEnvironment();
        $filters = DevOpsUtilities::createQueryFiltered($conditions);
        $organizationId = $environment->getCurrentOrganizationId();
        return InstanceProvider::getRepository()->getTaskReplanningReason()->findTaskReplanningReason($organizationId, $filters);
    }
    
    public function needTaskReplanningReason($originProjectId)
    {
        $projectRepository = InstanceProvider::getRepository()->getProject();
        $projectTypeRepository = InstanceProvider::getRepository()->getProjectType();
        $projectEntity = $projectRepository->find($originProjectId);
        $projectTypeEntity = $projectTypeRepository->find($projectEntity->getProjectType());
        $needTaskReplanningReason = false;
        if($projectTypeEntity->getUseTimePlanning() === Entities\ProjectType::IS_USE_TIME_PLANNING
            && $projectEntity->getprojectStatus()->getControl() === Entities\TaskStatus::TASK_STATUS_CONTROL_PROGRESS){
                $needTaskReplanningReason = true;
        }
        return array('needTaskReplanningReason' => $needTaskReplanningReason);  
    }
    
    public function createTaskReplanningReason($replanningReasonId, $taskId, $originProjectId, $destinyProjectId)
    {
        $replanningReason     = InstanceProvider::getRepository()->getReplanningReason()->find($replanningReasonId);
        $task                 = InstanceProvider::getRepository()->getTask()->find($taskId);
        $originProject        = InstanceProvider::getRepository()->getProject()->find($originProjectId);
        $destinyProject       = InstanceProvider::getRepository()->getProject()->find($destinyProjectId);
        $taskReplanningReason = InstanceProvider::getFactory()
                                                ->getTaskReplanningReason()
                                                ->createTaskReplanningReason($replanningReason, $task, $originProject, $destinyProject);
        $this->entityManager->persist($taskReplanningReason);
        $this->entityManager->flush();
    }
}